@@ -405,6 +405,7 @@ NM_DEVICE_TYPE_INFINIBAND = 9
 NM_DEVICE_TYPE_BOND = 10
 NM_DEVICE_TYPE_VLAN = 11
 NM_DEVICE_TYPE_ADSL = 12
+NM_DEVICE_TYPE_BRIDGE = 13
 NM_DEVICE_CAP_NONE = 0
 NM_DEVICE_CAP_NM_SUPPORTED = 1
 NM_DEVICE_CAP_CARRIER_DETECT = 2
@@ -416,7 +417,8 @@ NM_WIFI_DEVICE_CAP_CIPHER_CCMP = 8
 NM_WIFI_DEVICE_CAP_WPA = 16
 NM_WIFI_DEVICE_CAP_RSN = 32
 NM_WIFI_DEVICE_CAP_AP = 64
-NM_WIFI_DEVICE_CAP_IBSS_RSN = 128
+NM_WIFI_DEVICE_CAP_ADHOC = 128
+NM_WIFI_DEVICE_CAP_IBSS_RSN = 256
 NM_802_11_AP_FLAGS_NONE = 0
 NM_802_11_AP_FLAGS_PRIVACY = 1
 NM_802_11_AP_SEC_NONE = 0
@@ -433,6 +435,7 @@ NM_802_11_AP_SEC_KEY_MGMT_802_1X = 512
 NM_802_11_MODE_UNKNOWN = 0
 NM_802_11_MODE_ADHOC = 1
 NM_802_11_MODE_INFRA = 2
+NM_802_11_MODE_AP = 3
 NM_BT_CAPABILITY_NONE = 0
 NM_BT_CAPABILITY_DUN = 1
 NM_BT_CAPABILITY_NAP = 2
@@ -441,6 +444,7 @@ NM_DEVICE_MODEM_CAPABILITY_POTS = 1
 NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO = 2
 NM_DEVICE_MODEM_CAPABILITY_GSM_UMTS = 4
 NM_DEVICE_MODEM_CAPABILITY_LTE = 8
+NM_DEVICE_MODEM_CAPABILITY_OFONO = 16
 NM_DEVICE_STATE_UNKNOWN = 0
 NM_DEVICE_STATE_UNMANAGED = 10
 NM_DEVICE_STATE_UNAVAILABLE = 20
@@ -506,11 +510,15 @@ NM_DEVICE_STATE_REASON_GSM_SIM_WRONG = 48
 NM_DEVICE_STATE_REASON_INFINIBAND_MODE = 49
 NM_DEVICE_STATE_REASON_DEPENDENCY_FAILED = 50
 NM_DEVICE_STATE_REASON_BR2684_FAILED = 51
+NM_DEVICE_STATE_REASON_MODEM_MANAGER_UNAVAILABLE = 52
+NM_DEVICE_STATE_REASON_SSID_NOT_FOUND = 53
+NM_DEVICE_STATE_REASON_SECONDARY_CONNECTION_FAILED = 54
 NM_DEVICE_STATE_REASON_LAST = 65535
 NM_ACTIVE_CONNECTION_STATE_UNKNOWN = 0
 NM_ACTIVE_CONNECTION_STATE_ACTIVATING = 1
 NM_ACTIVE_CONNECTION_STATE_ACTIVATED = 2
 NM_ACTIVE_CONNECTION_STATE_DEACTIVATING = 3
+NM_ACTIVE_CONNECTION_STATE_DEACTIVATED = 4
 NM_VPN_SERVICE_STATE_UNKNOWN = 0
 NM_VPN_SERVICE_STATE_INIT = 1
 NM_VPN_SERVICE_STATE_SHUTDOWN = 2
